\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{visnyk-fizyka}[Base class of articles for Visnyk Fizyka]

\LoadClass[12pt,a4paper,reqno,twoside]{article}
\RequirePackage{fontspec}


\setmainfont[
    Extension = .ttf,
    UprightFont    = fonts/liberation/serif,
    BoldFont       = fonts/liberation/serifb,
    ItalicFont     = fonts/liberation/serifi,
    BoldItalicFont = fonts/liberation/serifbi
]{Liberation Serif}


%\RequirePackage[subpreambles=true]{standalone}
\RequirePackage{import}
\RequirePackage{polyglossia}
\setmainlanguage{ukrainian}
\setotherlanguage{english}
\setotherlanguage{russian}
%\RequirePackage[ukrhyph]

%\setromanfont[Mapping=tex-text]{Times New Roman}

\RequirePackage{longtable}
%\RequirePackage{csquotes}
\RequirePackage[left=30mm,top=20mm,right=15mm,bottom=20mm]{geometry}
\RequirePackage{mathtools,amsfonts,amssymb,amsthm,graphicx,amscd,latexsym,fancyhdr,cite,wrapfig}
\RequirePackage[mathcal]{euscript}
\RequirePackage[all]{xy}
\RequirePackage{multicol}
\RequirePackage[font=small]{caption}
\RequirePackage{tocloft}
\RequirePackage[explicit]{titlesec}
\RequirePackage{siunitx}
\RequirePackage{xifthen}
\RequirePackage{etoolbox}

\RequirePackage{float}
\RequirePackage{hyperref}
\RequirePackage{isorot}
\RequirePackage{multirow}
\RequirePackage{caption}
\RequirePackage{array}
\RequirePackage{tabularx}
\RequirePackage{gensymb}
\urlstyle{same}
\RequirePackage{titletoc}
\RequirePackage{tocloft}
\RequirePackage{floatflt}

%\usepackage{showframe}
%\DeclareSIUnit\metre{м}
%\DeclareSIUnit\kilo{к}

\columnsep   = 0.5cm  %Відстань між колонками
\parindent   = 1cm    %Відступ параграфа
\flushbottom%\raggedbottom
\setlength{\parskip}{0pt}
\raggedcolumns
\raggedbottom
\titleformat{\section}
  {\normalfont\bfseries\large}{\thesection}{2em}{#1}
\titleformat{\subsection}
  {\normalfont\bfseries}{\thesubsection}{2em}{#1}

 \renewenvironment{abstract}
     {\par\footnotesize\parindent\z@}
     {\par\nobreak\bigskip}

\newcommand{\keywords}[1]{{\it\bf Ключові слова:} #1}
\newcommand{\keywordsRusO}[1]{{\it\bf Ключевые слова:} #1}
\newcommand{\keywordsEngO}[1]{{\it\bf Keywords:} #1}
\cftsetindents{subsection}{-1mm}{1cm}
\setcounter{secnumdepth}{0}

\newcommand{\nombreindice}{\Large Content}
\newlistof{indice}{tce}{\nombreindice}
\newcommand\sectce[1]{%
   \addcontentsline{tce}{subsection}{#1}}

\newcommand{\makePretitle}{
    \pagebreak
    \addtocontents{toc}{\protect\setcounter{tocdepth}{2}}

    \addcontentsline{toc}{subsection}{\textit{\@authors}\\
    \@title}

    \addtocontents{toc}{\protect\setcounter{tocdepth}{-1}}

\addtocontents{tce}{\protect\setcounter{tocdepth}{2}}
\sectce{\textit{\@authorsEnCont}\\ \@titleEnCont}
    \begin{flushleft}
    \begin{tabular}{ l l }
         {\bf УДК} & \@udk \\
         {\bf PACS} & \@pacs \\
         {\bf DOI} & \@doi
    \end{tabular}
    \end{flushleft}
}

\newcommand{\makeUkrTitle}{
    \vbox{ \begin{flushleft}
        \vspace*{0cm}
        {\large \@authorsUkr}\par
        \vspace*{0.25cm}
        {\small\@universityUkr}\par
        \vspace*{0.3cm}
       \end{flushleft}
       \vspace{-0.8cm}
    \begin{center}
        {\LARGE\linespread{1}\selectfont \@titleUkr\par}
        \vspace*{0.40cm}
    \end{center}
    }
    \begin{abstract}
    \@abstractUkr\\
    \keywords{\@keywordsUkr}
    \end{abstract}
}


\newcommand{\makeRusTitle}{
   \vbox{
        \begin{flushleft}
        \vspace*{0.5cm}
        {\large \@authorsRus}\\
        \vspace*{0.25cm}
        {\small\@universityRus}\\
        \vspace*{0.3cm}
        \end{flushleft}
        \vspace{-0.8cm}
        \begin{center}
        {\LARGE\linespread{1}\selectfont \@titleRus\par}
        \vspace*{0.75cm}
    \end{center}
    }
    \begin{abstract}
        \@abstractRus\\
        %\keywords{\@keywordsRus}
          \keywordsRusO{\@keywordsRus}
    \end{abstract}
}

\newcommand{\makeEngTitle}{
    \pagebreak
   \vbox{ \begin{flushleft}
        \vspace*{0.5cm}
        {\large \@authorsEng}\\
        \vspace*{0.25cm}
        {\small\@universityEng}\\
        \vspace*{0.3cm}
        \end{flushleft}
        \vspace{-0.8cm}
    \begin{center}
        {\LARGE\linespread{1}\selectfont \@titleEng\par}
        \vspace*{0.75cm}
    \end{center}
    }
    \begin{abstract}
        \@abstractEng\\
       % \keywords{\@keywordsEng}
        \keywordsEngO{\@keywordsEng}
    \end{abstract}
}


\newcommand\my@message[1]{{\protect\textbf{(WARNING!)} #1 }}

%Власні змінні
\def\issueNum#1{\gdef\@issueNum{#1}}
\def\@issueNum{НЕ ВКАЗАНО}

\newcommand{\@defVar}[2]{
    \@namedef{#1}##1{
        \ifthenelse{\isempty{##1}}{
            \@namedef{@#1}{\my@message{#2}}
        }{
            \@namedef{@#1}{##1}
        }
    }
    \@namedef{@#1}{\my@message{#2}}
}

% Глобальні змінні
\@defVar{issueNum}{0}

% Змінні статей
\@defVar{udk}{ТУТ ПУСТО}
\@defVar{pacs}{ТУТ ПУСТО}
\@defVar{doi}{ТУТ ПУСТО}

\@defVar{titleUkr}{ЗАГОЛОВОК УКРАЇНСЬКОЮ НЕ ВКАЗАНО}
\@defVar{authorsUkr}{АВТОРИ УКРАЇНСЬКОЮ НЕ ВКАЗАНІ}
\@defVar{universityUkr}{УНІВЕРСИТЕТ УКРАЇНСЬКОЮ НЕ ВКАЗАНО}
\@defVar{abstractUkr}{АНОТАЦІЯ УКРАЇНСЬКОЮ НЕ ВКАЗАНА}
\@defVar{keywordsUkr}{КЛЮЧОВІ СЛОВА УКРАЇНСЬКОЮ НЕ ВКАЗАНІ}

\@defVar{titleRus}{ЗАГОЛОВОК РОСІЙСЬКОЮ НЕ ВКАЗАНО}
\@defVar{authorsRus}{АВТОРИ РОСІЙСЬКОЮ НЕ ВКАЗАНІ}
\@defVar{universityRus}{УНІВЕРСИТЕТ РОСІЙСЬКОЮ НЕ ВКАЗАНО}
\@defVar{abstractRus}{АНОТАЦІЯ РОСІЙСЬКОЮ НЕ ВКАЗАНА}
\@defVar{keywordsRus}{КЛЮЧОВІ СЛОВА РОСІЙСЬКОЮ НЕ ВКАЗАНІ}

\@defVar{titleEng}{ЗАГОЛОВОК АНГЛІЙСЬКОЮ НЕ ВКАЗАНО}
\@defVar{authorsEng}{АВТОРИ АНГЛІЙСЬКОЮ НЕ ВКАЗАНІ}
\@defVar{universityEng}{УНІВЕРСИТЕТ АНГЛІЙСЬКОЮ НЕ ВКАЗАНО}
\@defVar{abstractEng}{АНОТАЦІЯ АНГЛІЙСЬКОЮ НЕ ВКАЗАНА}
\@defVar{keywordsEng}{КЛЮЧОВІ СЛОВА АНГЛІЙСЬКОЮ НЕ ВКАЗАНІ}

\@defVar{authors}{\@authorsUkr}
\@defVar{authorsEnCont}{\@authorsEng}
\@defVar{titleEnCont}{}


\newcommand{\@oddtopheader}{\selectlanguage{ukrainian} Науковий вісник Ужгородського університету. Серія Фізика. Випуск \@issueNum. — 2019}
\newcommand{\@eventopheader}{\selectlanguage{english} Uzhhorod University Scientific Herald. Series Physics. Issue \@issueNum. — 2019}

\pagestyle{fancy}
\fancyhead{}\fancyfoot{}
\fancyhead[CO]{\footnotesize\@oddtopheader}
\fancyhead[CE]{\footnotesize\rm \@eventopheader}

\fancyfoot[CO]{\footnotesize\rm \thepage}
\fancyfoot[CE]{\footnotesize\rm \thepage}

\headwidth=170mm
\renewcommand{\headrulewidth}{0pt}
